@@ -3,12 +3,12 @@ import os, time, winsound
 def drew():
     os.system('cls')
     directory = os.path.dirname(os.path.abspath(__file__))
-    #frameDirectory = os.path.join(directory, "Frames")
-    frameDirectory = directory
+    frameDirectory = os.path.join(directory, "Frames")
+    #frameDirectory = directory
     frames = []
     cycles = 3
-    #audioDirectory = os.path.join(directory, "Audio")
-    audioDirectory = directory
+    audioDirectory = os.path.join(directory, "Audio")
+    #audioDirectory = directory
     soundFile = os.path.join(audioDirectory, "stayinAlive.wav")
 
     for filename in os.listdir(frameDirectory):
